@@ -1,4 +1,4 @@
-//@line 38 "/builds/tinderbox/Xr-Mozilla1.9-Release/Darwin_8.8.4_Depend/mozilla/toolkit/components/nsDefaultCLH.js"
+//@line 38 "/builds/slave/191-osx-xr/build/toolkit/components/nsDefaultCLH.js"
 
 const nsISupports              = Components.interfaces.nsISupports;
 
@@ -78,6 +78,10 @@ var nsDefaultCLH = {
       dump(out + "\n");
       Components.utils.reportError(out);
     }
+    
+    if (cmdLine.handleFlag("silent", false)) {
+      cmdLine.preventDefault = true;
+    }
 
     if (cmdLine.preventDefault)
       return;
