@@ -154,14 +154,18 @@ pref("gfx.color_management.display_profile", "");
 pref("gfx.color_management.rendering_intent", 0);
 
 pref("gfx.downloadable_fonts.enabled", true);
+pref("gfx.downloadable_fonts.sanitize", true);
+//@line 160 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+pref("gfx.downloadable_fonts.sanitize.preserve_otl_tables", false);
+//@line 164 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
-//@line 176 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 182 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 // Only on mac tabfocus is expected to handle UI widgets as well as web content
 pref("accessibility.tabfocus_applies_to_xul", true);
-//@line 179 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 185 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -509,9 +513,9 @@ pref("dom.storage.default_quota",      5120);
 
 // Parsing perf prefs. For now just mimic what the old code did.
 pref("content.sink.event_probe_rate", 3);
-//@line 527 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 533 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 pref("content.sink.pending_event_mode", 0);
-//@line 529 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 535 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Disable popups from plugins by default
 //   0 = openAllowed
@@ -556,9 +560,9 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 574 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 580 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.help", false);
-//@line 576 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 582 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -717,6 +721,9 @@ pref("network.IDN.whitelist.xn--fiqz9s", true); // Traditional
 pref("network.IDN.whitelist.xn--fiqs8s", true); // Simplified
 // hk, Hong Kong, .<Hong Kong>
 pref("network.IDN.whitelist.xn--j6w193g", true);
+// ir, Iran, <.Iran> with variants
+pref("network.IDN.whitelist.xn--mgba3a4f16a", true);
+pref("network.IDN.whitelist.xn--mgba3a4fra", true);
 // jo, Jordan, .<Al-Ordon>
 pref("network.IDN.whitelist.xn--mgbayh7gpa", true);
 // ru, Russian Federation, .<RF>
@@ -816,7 +823,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 839 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 848 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -835,9 +842,9 @@ pref("network.ntlm.send-lm-response", false);
 
 pref("permissions.default.image",           1); // 1-Accept, 2-Deny, 3-dontAcceptForeign
 
-//@line 864 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 873 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 pref("network.proxy.type",                  0);
-//@line 866 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 875 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
 pref("network.proxy.ftp",                   "");
 pref("network.proxy.ftp_port",              0);
@@ -1199,9 +1206,9 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1606 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1615 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 1608 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1617 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 // Mac specific preference defaults
 pref("browser.drag_out_of_frame_style", 1);
 pref("ui.key.saveLink.shift", false); // true = shift, false = meta
@@ -1615,21 +1622,21 @@ pref("print.print_extra_margin", 90); // twips (90 twips is an eigth of an inch)
 // See bug 404131, topmost <panel> element wins to Dashboard on MacOSX.
 pref("ui.panel.default_level_parent", false);
 
-//@line 2023 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2032 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2224 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2233 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2318 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2327 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2591 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2600 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2659 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2668 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2685 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2694 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2705 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2714 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2713 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2722 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1653,7 +1660,7 @@ pref("image.cache.size", 5242880);
 // Size is given a weight of 1000 - timeweight.
 pref("image.cache.timeweight", 500);
 
-//@line 2742 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2751 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
